%bcond_with tests

Name:       patool
Version:    2.1.1
Release:    %mkrel 1
Summary:    Portable command line archive file manager
License:    GPLv2+
Group:      Archiving/Compression
Url:        https://wummel.github.io/patool
# Source0:  https://wummel.github.io/%%{name}/dist/%%{name}-%%{version}.tar.gz
Source0:    https://pypi.python.org/packages/source/p/%{name}/%{name}-%{version}.tar.gz
BuildArch:  noarch
BuildRequires:  python3-devel
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(argcomplete)

%if %{with tests}
BuildRequires:  python3dist(pytest)
BuildRequires:  arj, archmage, bzip2, bzip3, cabextract, chmlib, cpio
BuildRequires:  cdrkit-genisoimage, cdrkit-isotools, dpkg, flac, gzip,
BuildRequires:  lbzip2, lcab, lha, lz4, lzip, lzop, mac, mscompress
BuildRequires:  nomarch, ncompress, p7zip, pbzip2, sharutils
BuildRequires:  shorten, unrar, xz, zip, zopfli, zstd, unzip
#BuildRequires:  unace, star, mac, lrzip
%endif

%description
Various archive types can be created, extracted, tested and listed by
patool. The advantage of patool is its simplicity in handling archive
files without having to remember a myriad of programs and options.

The archive format is determined by the file(1) program and as a
fallback by the archive file extension.

patool supports 7z (.7z), ACE (.ace), ALZIP (.alz), AR (.a), ARC (.arc),
ARJ (.arj), BZIP2 (.bz2), CAB (.cab), compress (.Z), CPIO (.cpio),
DEB (.deb), DMS (.dms), GZIP (.gz), LRZIP (.lrz), LZH (.lha, .lzh), LZIP (.lz),
LZMA (.lzma), LZOP (.lzo), RPM (.rpm), RAR (.rar), RZIP (.rz), TAR (.tar),
XZ (.xz), ZIP (.zip, .jar) and ZOO (.zoo) formats. It relies on helper
applications to handle those archive formats (for example bzip2 for
BZIP2 archives).

The archive formats TAR (.tar), ZIP (.zip), BZIP2 (.bz2) and GZIP (.gz)
are supported natively and do not require helper applications to be
installed.


%prep
%autosetup -p1

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files patoolib

install -Dpm0644 doc/patool.1 %{buildroot}%{_mandir}/man1/patool.1
install -dm755 %{buildroot}%{_datadir}/bash-completion/completions
register-python-argcomplete patool > \
        %{buildroot}%{_datadir}/bash-completion/completions/patool

%check
%pyproject_check_import
# test but don't stop on failure. false-positive issues!?.
%{?with_tests:%pytest tests || true}

%files -f %{pyproject_files}
%license COPYING
%doc doc/*.txt
%{_bindir}/patool
%{_datadir}/bash-completion/completions/patool
%{_mandir}/man1/patool.1.*


%changelog
* Fri Feb 09 2024 daviddavid <daviddavid> 2.1.1-1.mga10
+ Revision: 2039830
- new version: 2.1.1 (fixes mga#32811, thanks to  Aurelian R)
- rebuild for py3.12
- switch to pyproject

* Wed Mar 23 2022 umeabot <umeabot> 1.12-7.mga9
+ Revision: 1823988
- Mageia 9 Mass Rebuild

* Sun Feb 27 2022 mrambo3501 <mrambo3501> 1.12-6.mga9
+ Revision: 1786278
- rebuild for python-3.10

* Sat Jun 26 2021 wally <wally> 1.12-5.mga9
+ Revision: 1732969
- Rebuild for python 3.9

* Thu Feb 27 2020 daviddavid <daviddavid> 1.12-4.mga8
+ Revision: 1550908
- port to python3
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 1.12-3.mga7
+ Revision: 1281515
- Mageia 7 Mass Rebuild

* Fri Sep 15 2017 tv <tv> 1.12-2.mga7
+ Revision: 1154019
- fix SRPM creation due to bad %%py2_install call
- also fix build

* Fri Mar 04 2016 shlomif <shlomif> 1.12-1.mga6
+ Revision: 985718
- New version 1.12

* Fri Dec 18 2015 daviddavid <daviddavid> 1.10-2.mga6
+ Revision: 911619
- use new python macros
- fix owner of python2_sitelib/patoolib/ dir

* Thu Dec 17 2015 shlomif <shlomif> 1.10-1.mga6
+ Revision: 911405
- Add missing BR
- New version 1.10

* Fri Jun 26 2015 shlomif <shlomif> 1.7-1.mga6
+ Revision: 844535
- New version 1.7

* Wed Oct 15 2014 umeabot <umeabot> 1.5-5.mga5
+ Revision: 742708
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.5-4.mga5
+ Revision: 727534
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.5-3.mga5
+ Revision: 683354
- Mageia 5 Mass Rebuild
+ pterjan <pterjan>
- Rebuild for new Python

* Sat May 10 2014 shlomif <shlomif> 1.5-1.mga5
+ Revision: 621731
- New version 1.5

* Tue Oct 22 2013 umeabot <umeabot> 1.4-4.mga4
+ Revision: 542826
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.4-3.mga4
+ Revision: 498032
- Rebuild to add different pythonegg provides for python 2 and 3

* Fri Oct 04 2013 philippem <philippem> 1.4-2.mga4
+ Revision: 491550
+ rebuild (emptylog)

* Sun Sep 08 2013 sander85 <sander85> 1.4-1.mga4
+ Revision: 476057
- New version: 1.4

* Sun Jul 21 2013 sander85 <sander85> 1.3-1.mga4
+ Revision: 457020
- New version: 1.3
- Update URLs

* Sat May 25 2013 shlomif <shlomif> 1.1-1.mga4
+ Revision: 427485
- New version 1.1

* Sun Jan 13 2013 umeabot <umeabot> 0.16-4.mga3
+ Revision: 362462
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon May 28 2012 shlomif <shlomif> 0.16-3.mga3
+ Revision: 248717
- Fix the build with PYTHONDONTWRITEBYTECODE=1
- imported package patool

